<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Board</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No update available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading content %1 failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>CapturedImage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error Adding Image to Library</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>widgets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warnings during export was appeared</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>Audios</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Movies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ImportedImage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Editable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>French</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to start encoder ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Education</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Strong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Board</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Licences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Credits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>version : …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
